@@ -18,10 +18,12 @@
 
 import copy
 from typing import Optional, Tuple, Union
+import warnings
 
 import matplotlib.pyplot as plt
 import numpy as np
 
+from orix._util import deprecated, deprecated_argument
 from orix.crystal_map.crystal_map_properties import CrystalMapProperties
 from orix.crystal_map.phase_list import Phase, PhaseList
 from orix.quaternion import Orientation, Rotation
@@ -53,6 +55,15 @@ class CrystalMap:
     z
         Map z coordinate of each data point. If not given, the map is
         assumed to be 2D or 1D, and it is set to ``None``.
+
+        .. deprecated:: 0.10.1
+
+            Will be removed in 0.11.0. Support for 3D crystal maps is
+            minimal and brittle, and it was therefore decided to remove
+            it altogether. If you rely on this functionality, please
+            report it in an issue at
+            https://github.com/pyxem/orix/issues.
+
     phase_list
         A list of phases in the data with their with names, space
         groups, point groups, and structures. The order in which the
@@ -206,6 +217,7 @@ class CrystalMap:
     Scan unit: um
     """
 
+    @deprecated_argument(name="z", since="0.10.1", removal="0.11.0")
     def __init__(
         self,
         rotations: Rotation,
@@ -348,6 +360,7 @@ class CrystalMap:
             return self._y[self.is_in_data]
 
     @property
+    @deprecated(since="0.10.1", removal="0.11.0", object_type="property")
     def z(self) -> Union[None, np.ndarray]:
         """Return the z coordinates of points in data."""
         if self._z is None or len(np.unique(self._z)) == 1:
@@ -366,6 +379,7 @@ class CrystalMap:
         return self._step_size_from_coordinates(self._y)
 
     @property
+    @deprecated(since="0.10.1", removal="0.11.0", object_type="property")
     def dz(self) -> float:
         """Return the z coordiante step size."""
         return self._step_size_from_coordinates(self._z)
@@ -531,7 +545,11 @@ class CrystalMap:
         """Return the coordinates of points in the data."""
         # TODO: Make this "dynamic"/dependable when enabling specimen
         #  reference frame
-        return {"z": self.z, "y": self.y, "x": self.x}
+
+        # TODO: Remove after (any) one release after 0.10.1
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore", "Property ", np.VisibleDeprecationWarning)
+            return {"z": self.z, "y": self.y, "x": self.x}
 
     @property
     def _all_coordinates(self) -> dict:
@@ -545,7 +563,11 @@ class CrystalMap:
         """Return the step sizes of dimensions in the data."""
         # TODO: Make this "dynamic"/dependable when enabling specimen
         #  reference frame
-        return {"z": self.dz, "y": self.dy, "x": self.dx}
+
+        # TODO: Remove after (any) one release after 0.10.1
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore", "Property ", np.VisibleDeprecationWarning)
+            return {"z": self.dz, "y": self.dy, "x": self.dx}
 
     @property
     def _coordinate_axes(self) -> dict:
@@ -585,11 +607,8 @@ class CrystalMap:
             If ``str``, it must be a valid phase or ``"not_indexed"`` or
             ``"indexed"``. If ``slice`` or ``tuple``, it must be within
             the map shape. If ``int``, it must be a valid
-            :attr`self.id`. If boolean array, it must be of map shape.
+            :attr:`self.id`. If boolean array, it must be of map shape.
         """
-        # TODO: Crop new map to the extremal spatial values (e.g. if all values in first
-        #  or last row/column are masked out by the key), i.e. not just mask the values
-
         # Initiate a mask to be added to the returned copy of the
         # CrystalMap instance, to ensure that only the unmasked values
         # are in the data of the copy (True in `is_in_data`). First, no
@@ -597,8 +616,8 @@ class CrystalMap:
         # condition in the input key.
         is_in_data = np.zeros(self.size, dtype=bool)
 
-        # The original instance might already have set some points to
-        # not be in the data. If so, `is_in_data` is used to update the
+        # The original mask might already have set some points to not be
+        # in the data. If so, `is_in_data` is used to update the
         # original `is_in_data`. Since `new_is_in_data` is not initiated
         # for all key types, we declare it here and check for it later.
         new_is_in_data = None
@@ -630,12 +649,13 @@ class CrystalMap:
             for i, k in enumerate(key):
                 slices[i] = k
 
-            new_is_in_data = np.zeros(self._original_shape, dtype=bool)  # > 1D
-            new_is_in_data[tuple(slices)] = True
-            # Note that although all points within slice(s) was sought,
-            # points within the slice(s) which are already removed from
-            # the data are still kept out by this boolean multiplication
-            new_is_in_data = new_is_in_data.flatten() * self.is_in_data
+            new_is_in_data_slice = np.zeros(self.shape, dtype=bool)  # > 1D
+            new_is_in_data_slice[tuple(slices)] = True
+
+            # Insert new (sub)mask into old full mask
+            new_is_in_data = self.is_in_data.reshape(self._original_shape).copy()
+            new_is_in_data[self._data_slices_from_coordinates()] = new_is_in_data_slice
+            new_is_in_data = new_is_in_data.ravel()
 
         # Insert the mask into a mask with the full map shape, if not
         # done already
@@ -736,10 +756,29 @@ class CrystalMap:
         shape
             Map shape. Default is a 2D map of shape (5, 10), i.e. with
             five rows and ten columns.
+
+            .. deprecated:: 0.10.1
+
+            Returning coordinates for a 3D map is deprecated, and this
+            method will only support 1D or 2D maps in 0.11.0. Support
+            for 3D crystal maps is minimal and brittle, and it was
+            therefore decided to remove it altogether. If you rely on
+            this functionality, please report it in an issue at
+            https://github.com/pyxem/orix/issues.
+
         step_sizes
             Map step sizes. If not given, it is set to 1 px in each map
             direction given by ``shape``.
 
+            .. deprecated:: 0.10.1
+
+            Returning coordinates for a 3D map is deprecated, and this
+            method will only support 1D or 2D maps in 0.11.0. Support
+            for 3D crystal maps is minimal and brittle, and it was
+            therefore decided to remove it altogether. If you rely on
+            this functionality, please report it in an issue at
+            https://github.com/pyxem/orix/issues.
+
         Returns
         -------
         xmap
@@ -819,9 +858,6 @@ class CrystalMap:
         >>> iq.shape
         (100, 117)
         """
-        # TODO: Consider an `axes` argument along which to get map data
-        #  if > 2D
-
         # Get full map shape
         map_shape = self._original_shape
 
@@ -1100,23 +1136,42 @@ def create_coordinate_arrays(
 ) -> Tuple[dict, int]:
     """Create flattened coordinate arrays from a given map shape and
     step sizes, suitable for initializing a
-    :class:`~orix.crystal_map.CrystalMap`. Arrays for 1D, 2D, or 3D maps
-    can be returned.
+    :class:`~orix.crystal_map.CrystalMap`. Arrays for 1D or 2D maps can
+    be returned.
 
     Parameters
     ----------
     shape
         Map shape. Default is a 2D map of shape (5, 10) with five rows
-        and ten columns. Can be up to 3D.
+        and ten columns.
+
+        .. deprecated:: 0.10.1
+
+            Returning coordinates for a 3D map is deprecated, and this
+            method will only support 1D or 2D maps in 0.11.0. Support
+            for 3D crystal maps is minimal and brittle, and it was
+            therefore decided to remove it altogether. If you rely on
+            this functionality, please report it in an issue at
+            https://github.com/pyxem/orix/issues.
+
     step_sizes
         Map step sizes. If not given, it is set to 1 px in each map
         direction given by ``shape``.
 
+        .. deprecated:: 0.10.1
+
+            Returning coordinates for a 3D map is deprecated, and this
+            method will only support 1D or 2D maps in 0.11.0. Support
+            for 3D crystal maps is minimal and brittle, and it was
+            therefore decided to remove it altogether. If you rely on
+            this functionality, please report it in an issue at
+            https://github.com/pyxem/orix/issues.
+
     Returns
     -------
     d
-        Dictionary with keys ``"z"``, ``"y"``, and ``"x"``, depending on
-        the length of ``shape``, with coordinate arrays.
+        Dictionary with keys ``"y"`` and ``"x"``, depending on the
+        length of ``shape``, with coordinate arrays.
     map_size
         Number of map points.
 
@@ -1136,6 +1191,17 @@ def create_coordinate_arrays(
     if step_sizes is None:
         step_sizes = (1,) * ndim
 
+    # TODO: Remove after (any) one release after 0.10.1
+    if ndim == 3:
+        warnings.warn(
+            "Returning coordinates for a 3D map is deprecated, and this function will "
+            "only support 1D or 2D maps in 0.11.0. Support for 3D crystal maps is "
+            "minimal and brittle, and it was therefore decided to remove it altogether."
+            " If you rely on this functionality, please report it in an issue at "
+            "https://github.com/pyxem/orix/issues",
+            np.VisibleDeprecationWarning,
+        )
+
     # Set up as if a 3D map is to be returned
     dz, dy, dx = (1,) * (3 - ndim) + step_sizes
     nz, ny, nx = (1,) * (3 - ndim) + shape
