@@ -18,26 +18,22 @@
 
 from matplotlib.patches import FancyArrowPatch
 from mpl_toolkits.mplot3d import proj3d
+import numpy as np
 
 
 class Arrow3D(FancyArrowPatch):
     """Matplotlib arrows in 3D with arrowheads.
 
-    Taken from this Stackoverflow answer by user CT Zhu
+    Initially taken from this Stack Overflow answer by user CT Zhu
     https://stackoverflow.com/a/22867877/12063126.
     """
 
     def __init__(self, xs, ys, zs, *args, **kwargs):
-        FancyArrowPatch.__init__(self, (0, 0), (0, 0), *args, **kwargs)
+        super().__init__((0, 0), (0, 0), *args, **kwargs)
         self._verts3d = xs, ys, zs
 
-    def draw(self, renderer):
+    def do_3d_projection(self, renderer=None):
         xs3d, ys3d, zs3d = self._verts3d
         xs, ys, zs = proj3d.proj_transform(xs3d, ys3d, zs3d, self.axes.M)
         self.set_positions((xs[0], ys[0]), (xs[1], ys[1]))
-        FancyArrowPatch.draw(self, renderer)
-        zorder = 1
-        return zorder
-
-    # matplotlib>=3.5 compatibility
-    do_3d_projection = draw
+        return np.min(zs)
