@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with orix.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Projections of :class:`orix.vector.Vector3d` to various other
+"""Projections of :class:`~orix.vector.Vector3d` to various other
 representations.
 """
 
@@ -25,7 +25,6 @@ from orix.projections.stereographic import (
     StereographicProjection,
 )
 
-# Lists what will be imported when calling "from orix.vector import *"
 __all__ = [
     "InverseStereographicProjection",
     "StereographicProjection",
