@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2021 the orix developers
+# Copyright 2018-2022 the orix developers
 #
 # This file is part of orix.
 #
@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with orix.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Conversions of orientations between many common representations from
+"""Conversions of rotations between many common representations from
 :cite:`rowenhorst2015consistent`, accelerated with Numba.
 
 This module and documentation is only relevant for orix developers, not
@@ -32,19 +32,19 @@ import numpy as np
 
 
 @nb.jit("int64(float64[:])", cache=True, nogil=True, nopython=True)
-def get_pyramid_single(xyz):
+def get_pyramid_single(xyz: np.ndarray) -> int:
     """Determine to which out of six pyramids in the cube a (x, y, z)
     coordinate belongs.
 
     Parameters
     ----------
-    xyz : numpy.ndarray
+    xyz
         1D array (x, y, z) of 64-bit floats.
 
     Returns
     -------
-    pyramid : int
-        Which pyramid `xyz` belongs to as a 64-bit integer.
+    pyramid
+        Which pyramid ``xyz`` belongs to as a 64-bit integer.
 
     Notes
     -----
@@ -67,19 +67,56 @@ def get_pyramid_single(xyz):
         return 6
 
 
+@nb.jit("int64[:](float64[:, :])", cache=True, nogil=True, nopython=True)
+def get_pyramid_2d(xyz: np.ndarray) -> np.ndarray:
+    """Determine to which out of six pyramids in the cube a 2D array of
+    (x, y, z) coordinates belongs.
+
+    Parameters
+    ----------
+    xyz
+        2D array of n (x, y, z) as 64-bit floats.
+
+    Returns
+    -------
+    pyramids
+        1D array of pyramids as 64-bit integers.
+
+    Notes
+    -----
+    This function is optimized with Numba, so care must be taken with
+    array shapes and data types.
+    """
+    n_scalars = xyz.shape[0]
+    pyramids = np.zeros(n_scalars, dtype=np.int64)
+    for i in nb.prange(n_scalars):
+        pyramids[i] = get_pyramid_single(xyz[i])
+    return pyramids
+
+
+def get_pyramid(xyz: np.ndarray) -> np.ndarray:
+    """n-dimensional wrapper for get_pyramid_2d, see the docstring of
+    that function.
+    """
+    n_xyz = np.prod(xyz.shape[:-1])
+    xyz2d = xyz.astype(np.float64).reshape(n_xyz, 3)
+    pyramids = get_pyramid_2d(xyz2d).reshape(n_xyz)
+    return pyramids
+
+
 @nb.jit("float64[:](float64[:])", cache=True, nogil=True, nopython=True)
-def cu2ho_single(cu):
+def cu2ho_single(cu: np.ndarray) -> np.ndarray:
     """Conversion from a single set of cubochoric coordinates to
     un-normalized homochoric coordinates :cite:`singh2016orientation`.
 
     Parameters
     ----------
-    cu : numpy.ndarray
+    cu
         1D array of (x, y, z) as 64-bit floats.
 
     Returns
     -------
-    ho : numpy.ndarray
+    ho
         1D array of (x, y, z) as 64-bit floats.
 
     Notes
@@ -131,8 +168,8 @@ def cu2ho_single(cu):
                 q = prefactor * y / np.sqrt(sqrt2 - cosq)
                 t1 = sqrt2 * sinq * q
                 t2 = (sqrt2 * cosq - 1) * q
-            c = t1 ** 2 + t2 ** 2
-            s = np.pi * c / (24 * z ** 2)
+            c = t1**2 + t2**2
+            s = np.pi * c / (24 * z**2)
             c = np.sqrt(np.pi) * c / np.sqrt(24) / z
             q = np.sqrt(1 - s)
 
@@ -147,18 +184,18 @@ def cu2ho_single(cu):
 
 
 @nb.jit("float64[:, :](float64[:, :])", cache=True, nogil=True, nopython=True)
-def cu2ho(cu):
+def cu2ho_2d(cu: np.ndarray) -> np.ndarray:
     """Conversion from multiple cubochoric coordinates to un-normalized
     homochoric coordinates :cite:`singh2016orientation`.
 
     Parameters
     ----------
-    cu : numpy.ndarray
+    cu
         2D array of n (x, y, z) as 64-bit floats.
 
     Returns
     -------
-    ho : numpy.ndarray
+    ho
         2D array of n (x, y, z) as 64-bit floats.
 
     Notes
@@ -166,25 +203,35 @@ def cu2ho(cu):
     This function is optimized with Numba, so care must be taken with
     array shapes and data types.
     """
-    ho = np.zeros_like(cu)
+    ho = np.zeros_like(cu, dtype=np.float64)
     for i in nb.prange(cu.shape[0]):
         ho[i] = cu2ho_single(cu[i])
     return ho
 
 
+def cu2ho(cu: np.ndarray) -> np.ndarray:
+    """N-dimensional wrapper for cu2ho_2d, see the docstring of that
+    function.
+    """
+    n_cu = np.prod(cu.shape[:-1])
+    cu2d = cu.astype(np.float64).reshape(n_cu, 3)
+    ho = cu2ho_2d(cu2d).reshape(cu.shape)
+    return ho
+
+
 @nb.jit("float64[:](float64[:])", cache=True, nogil=True, nopython=True)
-def ho2ax_single(ho):
+def ho2ax_single(ho: np.ndarray) -> np.ndarray:
     """Conversion from a single set of homochoric coordinates to an
     un-normalized axis-angle pair :cite:`rowenhorst2015consistent`.
 
     Parameters
     ----------
-    ho : numpy.ndarray
+    ho
         1D array of (x, y, z) as 64-bit floats.
 
     Returns
     -------
-    ax : numpy.ndarray
+    ax
         1D array of (x, y, z, angle) as 64-bit floats.
 
     Notes
@@ -204,7 +251,7 @@ def ho2ax_single(ho):
         -2.401996891720091e-7,    4.386887017466388e-8,   -3.5917775353564864e-9
     ])
     # fmt: on
-    ho_magnitude = np.sum(ho ** 2)
+    ho_magnitude = np.sum(ho**2)
     if (ho_magnitude > -1e-8) and (ho_magnitude < 1e-8):
         ax = np.array([0, 0, 1, 0], dtype=np.float64)
     else:
@@ -224,19 +271,19 @@ def ho2ax_single(ho):
 
 
 @nb.jit("float64[:, :](float64[:, :])", cache=True, nogil=True, nopython=True)
-def ho2ax(ho):
+def ho2ax_2d(ho: np.ndarray) -> np.ndarray:
     """Conversion from multiple homochoric coordinates to un-normalized
     axis-angle pairs :cite:`rowenhorst2015consistent`.
 
     Parameters
     ----------
-    ho : numpy.ndarray
+    ho
         2D array of n (x, y, z) as 64-bit floats.
 
     Returns
     -------
-    ho : numpy.ndarray
-        2D array of n (x, y, z) as 64-bit floats.
+    ax
+        2D array of n (x, y, z, angle) as 64-bit floats.
 
     Notes
     -----
@@ -250,19 +297,29 @@ def ho2ax(ho):
     return ax
 
 
+def ho2ax(ho: np.ndarray) -> np.ndarray:
+    """N-dimensional wrapper for ho2ax_2d, see the docstring of that
+    function.
+    """
+    n_ho = np.prod(ho.shape[:-1])
+    ho2d = ho.astype(np.float64).reshape(n_ho, 3)
+    ho = ho2ax_2d(ho2d).reshape(ho.shape[:-1] + (4,))
+    return ho
+
+
 @nb.jit("float64[:](float64[:])", cache=True, nogil=True, nopython=True)
-def ax2ro_single(ax):
+def ax2ro_single(ax: np.ndarray) -> np.ndarray:
     """Conversion from a single angle-axis pair to an un-normalized
     Rodrigues vector :cite:`rowenhorst2015consistent`.
 
     Parameters
     ----------
-    ax : numpy.ndarray
+    ax
         1D array of (x, y, z, angle) as 64-bit floats.
 
     Returns
     -------
-    ro : numpy.ndarray
+    ro
         1D array of (x, y, z, angle) as 64-bit floats.
 
     Notes
@@ -285,18 +342,18 @@ def ax2ro_single(ax):
 
 
 @nb.jit("float64[:, :](float64[:, :])", cache=True, nogil=True, nopython=True)
-def ax2ro(ax):
+def ax2ro_2d(ax: np.ndarray) -> np.ndarray:
     """Conversion from multiple axis-angle pairs to un-normalized
     Rodrigues vectors :cite:`rowenhorst2015consistent`.
 
     Parameters
     ----------
-    ax : numpy.ndarray
+    ax
         2D array of n (x, y, z, angle) as 64-bit floats.
 
     Returns
     -------
-    ro : numpy.ndarray
+    ro
         2D array of n (x, y, z, angle) as 64-bit floats.
 
     Notes
@@ -304,25 +361,35 @@ def ax2ro(ax):
     This function is optimized with Numba, so care must be taken with
     array shapes and data types.
     """
-    ro = np.zeros_like(ax)
+    ro = np.zeros_like(ax, dtype=np.float64)
     for i in nb.prange(ax.shape[0]):
         ro[i] = ax2ro_single(ax[i])
     return ro
 
 
+def ax2ro(ax: np.ndarray) -> np.ndarray:
+    """N-dimensional wrapper for ax2ro_2d, see the docstring of that
+    function.
+    """
+    n_ax = np.prod(ax.shape[:-1])
+    ax2d = ax.astype(np.float64).reshape(n_ax, 4)
+    ro = ax2ro_2d(ax2d).reshape(ax.shape)
+    return ro
+
+
 @nb.jit("float64[:](float64[:])", cache=True, nogil=True, nopython=True)
-def ro2ax_single(ro):
+def ro2ax_single(ro: np.ndarray) -> np.ndarray:
     """Conversion from a single Rodrigues vector to an un-normalized
     axis-angle pair :cite:`rowenhorst2015consistent`.
 
     Parameters
     ----------
-    ro : numpy.ndarray
+    ro
         1D array of (x, y, z, angle) as 64-bit floats.
 
     Returns
     -------
-    ax : numpy.ndarray
+    ax
         1D array of (x, y, z, angle) as 64-bit floats.
 
     Notes
@@ -340,18 +407,18 @@ def ro2ax_single(ro):
 
 
 @nb.jit("float64[:, :](float64[:, :])", cache=True, nogil=True, nopython=True)
-def ro2ax(ro):
+def ro2ax_2d(ro: np.ndarray) -> np.ndarray:
     """Conversion from multiple Rodrigues vectors to un-normalized
     axis-angle pairs :cite:`rowenhorst2015consistent`.
 
     Parameters
     ----------
-    ro : numpy.ndarray
+    ro
         2D array of n (x, y, z, angle) as 64-bit floats.
 
     Returns
     -------
-    ax : numpy.ndarray
+    ax
         2D array of n (x, y, z, angle) as 64-bit floats.
 
     Notes
@@ -366,19 +433,29 @@ def ro2ax(ro):
     return ax
 
 
+def ro2ax(ro: np.ndarray) -> np.ndarray:
+    """N-dimensional wrapper for ro2ax_2d, see the docstring of that
+    function.
+    """
+    n_ro = np.prod(ro.shape[:-1])
+    ro2d = ro.astype(np.float64).reshape(n_ro, 4)
+    ax = ro2ax_2d(ro2d).reshape(ro.shape)
+    return ax
+
+
 @nb.jit("float64[:](float64[:])", cache=True, nogil=True, nopython=True)
-def ax2qu_single(ax):
+def ax2qu_single(ax: np.ndarray) -> np.ndarray:
     """Conversion from a single axis-angle pair to an un-normalized
     quaternion :cite:`rowenhorst2015consistent`.
 
     Parameters
     ----------
-    ax : numpy.ndarray
+    ax
         1D array of (x, y, z, angle) as 64-bit floats.
 
     Returns
     -------
-    qu : numpy.ndarray
+    qu
         1D array of (a, b, c, d) as 64-bit floats.
 
     Notes
@@ -395,18 +472,18 @@ def ax2qu_single(ax):
 
 
 @nb.jit("float64[:, :](float64[:, :])", cache=True, nogil=True, nopython=True)
-def ax2qu(ax):
+def ax2qu_2d(ax: np.ndarray) -> np.ndarray:
     """Conversion from multiple axis-angle pairs to un-normalized
     quaternions :cite:`rowenhorst2015consistent`.
 
     Parameters
     ----------
-    ax : numpy.ndarray
+    ax
         2D array of n (x, y, z, angle) as 64-bit floats.
 
     Returns
     -------
-    qu : numpy.ndarray
+    qu
         2D array of n (a, b, c, d) as 64-bit floats.
 
     Notes
@@ -421,19 +498,29 @@ def ax2qu(ax):
     return qu
 
 
+def ax2qu(ax: np.ndarray) -> np.ndarray:
+    """N-dimensional wrapper for ax2qu_2d, see the docstring of that
+    function.
+    """
+    n_ax = np.prod(ax.shape[:-1])
+    ax2d = ax.astype(np.float64).reshape(n_ax, 4)
+    qu = ax2qu_2d(ax2d).reshape(ax.shape)
+    return qu
+
+
 @nb.jit("float64[:](float64[:])", cache=True, nogil=True, nopython=True)
-def ho2ro_single(ho):
+def ho2ro_single(ho: np.ndarray) -> np.ndarray:
     """Conversion from a single set of homochoric coordinates to an
     un-normalized Rodrigues vector :cite:`rowenhorst2015consistent`.
 
     Parameters
     ----------
-    ho : numpy.ndarray
+    ho
         1D array of (x, y, z) as 64-bit floats.
 
     Returns
     -------
-    ro : numpy.ndarray
+    ro
         1D array of (x, y, z, angle) as 64-bit floats.
 
     Notes
@@ -445,18 +532,18 @@ def ho2ro_single(ho):
 
 
 @nb.jit("float64[:, :](float64[:, :])", cache=True, nogil=True, nopython=True)
-def ho2ro(ho):
+def ho2ro_2d(ho: np.ndarray) -> np.ndarray:
     """Conversion from multiple homochoric coordinates to un-normalized
     Rodrigues vectors :cite:`rowenhorst2015consistent`.
 
     Parameters
     ----------
-    ho : numpy.ndarray
+    ho
         2D array of n (x, y, z) as 64-bit floats.
 
     Returns
     -------
-    ax : numpy.ndarray
+    ax
         2D array of n (x, y, z, angle) as 64-bit floats.
 
     Notes
@@ -471,19 +558,29 @@ def ho2ro(ho):
     return ro
 
 
+def ho2ro(ho: np.ndarray) -> np.ndarray:
+    """N-dimensional wrapper for ho2ro_2d, see the docstring of that
+    function.
+    """
+    n_ho = np.prod(ho.shape[:-1])
+    ho2d = ho.astype(np.float64).reshape(n_ho, 3)
+    ro = ho2ro_2d(ho2d).reshape(ho.shape[:-1] + (4,))
+    return ro
+
+
 @nb.jit("float64[:](float64[:])", cache=True, nogil=True, nopython=True)
-def cu2ro_single(cu):
+def cu2ro_single(cu: np.ndarray) -> np.ndarray:
     """Conversion from a single set of cubochoric coordinates to an
     un-normalized Rodrigues vector :cite:`rowenhorst2015consistent`.
 
     Parameters
     ----------
-    cu : numpy.ndarray
+    cu
         1D array of (x, y, z) as 64-bit floats.
 
     Returns
     -------
-    ro : numpy.ndarray
+    ro
         1D array of (x, y, z, angle) as 64-bit floats.
 
     Notes
@@ -498,18 +595,18 @@ def cu2ro_single(cu):
 
 
 @nb.jit("float64[:, :](float64[:, :])", cache=True, nogil=True, nopython=True)
-def cu2ro(cu):
+def cu2ro_2d(cu: np.ndarray) -> np.ndarray:
     """Conversion from multiple cubochoric coordinates to un-normalized
     Rodrigues vectors :cite:`rowenhorst2015consistent`.
 
     Parameters
     ----------
-    cu : numpy.ndarray
+    cu
         2D array of n (x, y, z) as 64-bit floats.
 
     Returns
     -------
-    ro : numpy.ndarray
+    ro
         2D array of n (x, y, z, angle) as 64-bit floats.
 
     Notes
@@ -524,20 +621,30 @@ def cu2ro(cu):
     return ro
 
 
-@nb.jit("float64[:](float64, float64, float64)", cache=True, nogil=True, nopython=True)
-def eu2qu_single(alpha, beta, gamma):
+def cu2ro(cu: np.ndarray) -> np.ndarray:
+    """N-dimensional wrapper for cu2ro_2d, see the docstring of that
+    function.
+    """
+    n_cu = np.prod(cu.shape[:-1])
+    cu2d = cu.astype(np.float64).reshape(n_cu, 3)
+    ro = cu2ro_2d(cu2d).reshape(cu.shape[:-1] + (4,))
+    return ro
+
+
+@nb.jit("float64[:](float64[:])", cache=True, nogil=True, nopython=True)
+def eu2qu_single(eu: np.ndarray) -> np.ndarray:
     """Convert three Euler angles (alpha, beta, gamma) to a unit
     quaternion.
 
     Parameters
     ----------
-    alpha, beta, gamma : float
-        Euler angles in the Bunge convention in radians as 64-bit
-        floats.
+    eu
+        1D array of (alpha, beta, gamma) Euler angles given in radians
+        in the Bunge convention (ie, passive Z-X-Z) as 64-bit floats.
 
     Returns
     -------
-    qu : numpy.ndarray
+    qu
         1D unit quaternion (a, b, c, d) as 64-bit floats.
 
     Notes
@@ -547,18 +654,55 @@ def eu2qu_single(alpha, beta, gamma):
     This function is optimized with Numba, so care must be taken with
     array shapes and data types.
     """
-    sigma = 0.5 * np.add(alpha, gamma)
-    delta = 0.5 * np.subtract(alpha, gamma)
-    c = np.cos(beta / 2)
-    s = np.sin(beta / 2)
+    sigma = 0.5 * np.add(eu[0], eu[2])
+    delta = 0.5 * np.subtract(eu[0], eu[2])
+    c = np.cos(eu[1] / 2)
+    s = np.sin(eu[1] / 2)
 
     qu = np.zeros(4, dtype=np.float64)
-    qu[0] = c * np.cos(sigma)
-    qu[1] = -s * np.cos(delta)
-    qu[2] = -s * np.sin(delta)
-    qu[3] = -c * np.sin(sigma)
+    qu[0] = np.array(c * np.cos(sigma), dtype=np.float64)
+    qu[1] = np.array(-s * np.cos(delta), dtype=np.float64)
+    qu[2] = np.array(-s * np.sin(delta), dtype=np.float64)
+    qu[3] = np.array(-c * np.sin(sigma), dtype=np.float64)
 
     if qu[0] < 0:
         qu = -qu
 
     return qu
+
+
+@nb.jit("float64[:, :](float64[:, :])", cache=True, nogil=True, nopython=True)
+def eu2qu_2d(eu: np.ndarray) -> np.ndarray:
+    """Conversion from multiple Euler angles (alpha, beta, gamma) to unit
+    quaternions
+
+    Parameters
+    ----------
+    eu
+        2D array of n (alpha, beta, gamma) as 64-bit floats.
+
+    Returns
+    -------
+    qu
+        2D array of n (q0, q1, q2, q3) quaternions as 64-bit floats.
+
+    Notes
+    -----
+    This function is optimized with Numba, so care must be taken with
+    array shapes and data types.
+    """
+    n_vectors = eu.shape[0]
+    qu = np.zeros((n_vectors, 4), dtype=np.float64)
+    for i in nb.prange(n_vectors):
+        qu[i] = eu2qu_single(eu[i])
+    return qu
+
+
+def eu2qu(eu: np.ndarray) -> np.ndarray:
+    """N-dimensional wrapper for eu2qu_2d, see the docstring of that
+    function.
+    """
+    n_eu = np.prod(eu.shape[:-1])
+    eu2d = eu.astype(np.float64).reshape(n_eu, 3)
+    qu = eu2qu_2d(eu2d).reshape(eu.shape[:-1] + (4,))
+    return qu
