@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with orix.  If not, see <http://www.gnu.org/licenses/>.
 
-from math import cos, sin, tan, pi
+from math import cos, pi, sin, tan
 
 from diffpy.structure.spacegroups import sg225
 import numpy as np
@@ -25,7 +25,6 @@ import pytest
 from orix.quaternion import Quaternion, Rotation
 from orix.vector import AxAngle, Vector3d
 
-
 rotations = [
     (0.707, 0.0, 0.0, 0.707),
     (0.5, -0.5, -0.5, 0.5),
@@ -68,7 +67,7 @@ def vector(request):
 
 
 def test_init(rotation):
-    assert np.allclose(rotation.norm.data, 1)
+    assert np.allclose(rotation.norm, 1)
     assert rotation.improper.shape == rotation.shape
     assert np.count_nonzero(rotation.improper) == 0
 
@@ -81,7 +80,26 @@ def test_slice(rotation):
 
 def test_unit(rotation):
     assert isinstance(rotation.unit, Rotation)
-    assert np.allclose(rotation.unit.norm.data, 1)
+    assert np.allclose(rotation.unit.norm, 1)
+
+
+def test_equality():
+    r1 = Rotation.random((5,))
+    r1_copy = Rotation(r1)
+    r2 = Rotation.random((5,))
+    assert r1 == r1
+    assert r1_copy == r1
+    # test values not equal
+    assert r1 != r2
+    # test improper not equal
+    r1_copy.improper = ~r1.improper
+    assert r1_copy != r1
+    # test shape not equal
+    r3 = Rotation.random((5, 1))
+    assert r3 != r1
+    # test not Rotation returns False
+    assert r1 != 2
+    assert r1 != "test"
 
 
 @pytest.mark.parametrize(
@@ -224,7 +242,16 @@ class TestToFromEuler:
         assert np.allclose(e, e2.data)
 
     def test_mtex(self, e):
-        _ = Rotation.from_euler(e, convention="mtex")
+        _ = Rotation.from_euler(e, direction="mtex")
+
+    def test_direction_values(self, e):
+        r_mtex = Rotation.from_euler(e, direction="mtex")
+        r_c2l = Rotation.from_euler(e, direction="crystal2lab")
+        r_l2c = Rotation.from_euler(e, direction="lab2crystal")
+        r_default = Rotation.from_euler(e)
+        assert np.allclose(r_default.data, r_l2c.data)
+        assert np.allclose(r_mtex.data, r_c2l.data)
+        assert np.allclose((r_l2c * r_c2l).angle.data, 0)
 
     def test_direction_kwarg(self, e):
         _ = Rotation.from_euler(e, direction="lab2crystal")
@@ -233,15 +260,6 @@ class TestToFromEuler:
         with pytest.raises(ValueError, match="The chosen direction is not one of "):
             _ = Rotation.from_euler(e, direction="dumb_direction")
 
-    def test_unsupported_conv_to(self, e):
-        r = Rotation.from_euler(e)
-        with pytest.raises(ValueError, match="The chosen convention is not supported,"):
-            _ = r.to_euler(convention="unsupported")
-
-    def test_unsupported_conv_from(self, e):
-        with pytest.raises(ValueError, match="The chosen convention is not one of "):
-            _ = Rotation.from_euler(e, convention="unsupported")
-
     def test_edge_cases_to_euler(self):
         x = np.sqrt(1 / 2)
         q = Rotation(np.asarray([x, 0, 0, x]))
@@ -251,9 +269,57 @@ class TestToFromEuler:
 
     def test_passing_degrees_warns(self):
         with pytest.warns(UserWarning, match="Angles are assumed to be in radians, "):
-            r = Rotation.from_euler([90, 0, 0], convention="bunge")
+            r = Rotation.from_euler([90, 0, 0])
             assert np.allclose(r.data, [0.5253, 0, 0, -0.8509], atol=1e-4)
 
+    # TODO: Remove in 1.0
+    def test_from_euler_warns(self, e):
+        """Rotation.from_euler() warns only when "convention" argument
+        is passed.
+        """
+        with pytest.warns(None) as record:
+            _ = Rotation.from_euler(e)
+        assert len(record) == 0
+
+        msg = (
+            r"Argument `convention` is deprecated and will be removed in version 1.0. "
+            r"To avoid this warning, please do not use `convention`. "
+            r"Use `direction` instead. See the documentation of `from_euler\(\)` for "
+            "more details."
+        )
+        with pytest.warns(np.VisibleDeprecationWarning, match=msg):
+            _ = Rotation.from_euler(e, convention="whatever")
+
+    # TODO: Remove in 1.0
+    def test_from_euler_convention_mtex(self, e):
+        """Passing convention="mtex" to Rotation.from_euler() works but
+        warns.
+        """
+        rot1 = Rotation.from_euler(e, direction="crystal2lab")
+        with pytest.warns(np.VisibleDeprecationWarning, match=r"Argument `convention`"):
+            rot2 = Rotation.from_euler(e, convention="mtex")
+        assert np.allclose(rot1.data, rot2.data)
+
+    # TODO: Remove in 1.0
+    def test_to_euler_convention_warns(self, e):
+        """Rotation.to_euler() warns only when "convention" argument is
+        passed.
+        """
+        rot1 = Rotation.from_euler(e)
+
+        with pytest.warns(None) as record:
+            rot2 = rot1.to_euler()
+        assert len(record) == 0
+
+        msg = (
+            r"Argument `convention` is deprecated and will be removed in version 1.0. "
+            r"To avoid this warning, please do not use `convention`. "
+            r"See the documentation of `to_euler\(\)` for more details."
+        )
+        with pytest.warns(np.VisibleDeprecationWarning, match=msg):
+            rot3 = rot1.to_euler(convention="whatever")
+        assert np.allclose(rot2, rot3)
+
 
 @pytest.mark.parametrize(
     "rotation, improper, expected, improper_expected",
@@ -303,7 +369,21 @@ def test_unique_inverse():
     r = Rotation.random((20,))
     u, inverse = r.unique(return_inverse=True)
     m = u[inverse] * ~r
-    assert np.allclose(m.angle.data, 0)
+    assert np.allclose(m.angle, 0)
+
+
+def test_angle_with_outer():
+    shape = (5,)
+    r = Rotation.random(shape)
+    awo_self = r.angle_with_outer(r)
+    assert awo_self.shape == shape + shape
+    assert np.allclose(np.diag(awo_self), 0, atol=1e-6)
+    r2 = Rotation.random((6,))
+    dist = r.angle_with_outer(r2)
+    assert dist.shape == r.shape + r2.shape
+    dist2 = r2.angle_with_outer(r)
+    assert dist2.shape == r2.shape + r.shape
+    assert np.allclose(dist, dist2.T)
 
 
 @pytest.mark.parametrize(
@@ -444,6 +524,48 @@ def test_dot_outer_quat(rotation, improper, quaternion, expected):
     assert np.allclose(cosines.data, expected, atol=1e-4)
 
 
+def test_outer_lazy_rot():
+    r1 = Rotation.random((5, 3))
+    r2 = Rotation.random((11, 4))
+    r12 = r1.outer(r2)
+    r12_lazy = r1.outer(r2, lazy=True, chunk_size=20)
+    assert r12.shape == r12_lazy.shape
+    assert np.allclose(r12.data, r12_lazy.data)
+    assert np.allclose(r12.improper, r12_lazy.improper)
+    # different chunk size
+    r12_lazy2 = r1.outer(r2, lazy=True, chunk_size=3)
+    assert r12.shape == r12_lazy2.shape
+    assert np.allclose(r12.data, r12_lazy2.data)
+    assert np.allclose(r12.improper, r12_lazy2.improper)
+
+
+def test_outer_lazy_vec():
+    r = Rotation.random((5, 3))
+    v = Vector3d(np.random.rand(6, 4, 3)).unit
+    v2 = r.outer(v)
+    v2_lazy = r.outer(v, lazy=True, chunk_size=20)
+    assert isinstance(v2, Vector3d)
+    assert isinstance(v2_lazy, Vector3d)
+    assert v2.shape == v2_lazy.shape
+    assert np.allclose(v2.data, v2_lazy.data)
+    # different chunk size
+    v2_lazy2 = r.outer(v, lazy=True, chunk_size=3)
+    assert isinstance(v2_lazy2, Vector3d)
+    assert v2.shape == v2_lazy.shape
+    assert np.allclose(v2.data, v2_lazy2.data)
+
+
+def test_outer_lazy_progressbar_stdout(capsys):
+    r1 = Rotation.random((5, 3))
+    r2 = Rotation.random((6, 4))
+    _ = r1.outer(r2, lazy=True, progressbar=True)
+    out, _ = capsys.readouterr()
+    assert "Completed" in out
+    _ = r1.outer(r2, lazy=True, progressbar=False)
+    out, _ = capsys.readouterr()
+    assert not out
+
+
 @pytest.mark.parametrize(
     "rotation, expected",
     [
@@ -543,12 +665,5 @@ class TestFromAxesAngles:
     def test_from_axes_angles(self, rotations):
         axangle = AxAngle.from_rotation(rotations)
         rotations2 = Rotation.from_neo_euler(axangle)
-        rotations3 = Rotation.from_axes_angles(axangle.axis.data, axangle.angle.data)
+        rotations3 = Rotation.from_axes_angles(axangle.axis.data, axangle.angle)
         assert np.allclose(rotations2.data, rotations3.data)
-
-
-def test_to_euler_not_warning():
-    rot = Rotation(((0, 1, 0, 0), (1, 0, 0, 0), (1, 1, 0, 0)))
-    with pytest.warns(None) as record:
-        _ = rot.to_euler()
-    assert len(record) == 0
