@@ -16,13 +16,16 @@
 # You should have received a copy of the GNU General Public License
 # along with orix.  If not, see <http://www.gnu.org/licenses/>.
 
+import sys
+
 from diffpy.structure import Lattice, Structure
 from diffpy.structure.spacegroups import GetSpaceGroup
 import numpy as np
 import pytest
 
 from orix.crystal_map import Phase, PhaseList
-from orix.quaternion.symmetry import Symmetry, O
+from orix.crystal_map.phase_list import _new_structure_matrix_from_alignment
+from orix.quaternion.symmetry import O, Symmetry
 
 
 class TestPhase:
@@ -201,7 +204,7 @@ class TestPhase:
         assert p.__repr__() == new_desired_p_repr
         assert p2.__repr__() == desired_p_repr
 
-    def test_shallowcopy_phase(self):
+    def test_shallow_copy_phase(self):
         p = Phase(name="al", point_group="m-3m", color="C1")
         p2 = p
 
@@ -243,6 +246,112 @@ class TestPhase:
         assert p1.is_hexagonal
         assert not p2.is_hexagonal
 
+    def test_structure_matrix(self):
+        """Structure matrix is updated assuming e1 || a, e3 || c*."""
+        trigonal_lattice = Lattice(1.7, 1.7, 1.4, 90, 90, 120)
+        phase = Phase(point_group="321", structure=Structure(lattice=trigonal_lattice))
+        lattice = phase.structure.lattice
+
+        # Lattice parameters are unchanged
+        assert np.allclose(lattice.abcABG(), [1.7, 1.7, 1.4, 90, 90, 120])
+
+        # Structure matrix has changed internally, but not the input
+        # `Lattice` instance
+        assert not np.allclose(lattice.base, trigonal_lattice.base)
+
+        # The expected structure matrix
+        # fmt: off
+        assert np.allclose(
+            lattice.base,
+            [
+                [ 1.7,  0,     0  ],
+                [-0.85, 1.472, 0  ],
+                [ 0,    0,     1.4]
+            ],
+            atol=1e-3
+        )
+        # fmt: on
+
+        # Setting the structure also updates the lattice
+        phase2 = phase.deepcopy()
+        phase2.structure = Structure(lattice=trigonal_lattice)
+        assert np.allclose(phase2.structure.lattice.base, lattice.base)
+
+        # Getting new structure matrix without passing enough parameters
+        # raises an error
+        with pytest.raises(ValueError, match="At least two of x, y, z must be set."):
+            _ = _new_structure_matrix_from_alignment(lattice.base, x="a")
+
+    def test_triclinic_structure_matrix(self):
+        """Update a triclinic structure matrix."""
+        # diffpy.structure aligns e1 || a*, e3 || c* by default
+        lat = Lattice(2, 3, 4, 70, 100, 120)
+        # fmt: off
+        assert np.allclose(
+            lat.base,
+            [
+                [1.732, -0.938, -0.347],
+                [0,      2.819,  1.026],
+                [0,      0,      4    ]
+            ],
+            atol=1e-3
+        )
+        assert np.allclose(
+            _new_structure_matrix_from_alignment(lat.base, x="a", z="c*"),
+            [
+                [ 2,     0,     0    ],
+                [-1.5,   2.598, 0    ],
+                [-0.695, 1.179, 3.759]
+            ],
+            atol=1e-3
+        )
+        assert np.allclose(
+            _new_structure_matrix_from_alignment(lat.base, x="b", z="c*"),
+            [
+                [-1,    -1.732, 0    ],
+                [ 3,     0,     0    ],
+                [+1.368, 0.012, 3.759]
+            ],
+            atol=1e-3
+        )
+        # fmt: on
+
+    def test_lattice_vectors(self):
+        """Correct direct and reciprocal lattice vectors."""
+        trigonal_lattice = Lattice(1.7, 1.7, 1.4, 90, 90, 120)
+        phase = Phase(point_group="321", structure=Structure(lattice=trigonal_lattice))
+
+        a, b, c = phase.a_axis, phase.b_axis, phase.c_axis
+        ar, br, cr = phase.ar_axis, phase.br_axis, phase.cr_axis
+        # Coordinates in direct and reciprocal crystal reference frames
+        assert np.allclose([a.coordinates, ar.coordinates], [1, 0, 0])
+        assert np.allclose([b.coordinates, br.coordinates], [0, 1, 0])
+        assert np.allclose([c.coordinates, cr.coordinates], [0, 0, 1])
+        # Coordinates in cartesian crystal reference frame
+        assert np.allclose(a.data, [1.7, 0, 0])
+        assert np.allclose(b.data, [-0.85, 1.472, 0], atol=1e-3)
+        assert np.allclose(c.data, [0, 0, 1.4])
+        assert np.allclose(ar.data, [0.588, 0.340, 0], atol=1e-3)
+        assert np.allclose(br.data, [0, 0.679, 0], atol=1e-3)
+        assert np.allclose(cr.data, [0, 0, 0.714], atol=1e-3)
+
+    @pytest.mark.xfail(
+        sys.platform == "win32",
+        reason="Importing modules from CifFile fails on GitHub's windows server",
+        strict=True,
+    )
+    def test_from_cif(self, cif_file):
+        """CIF files parsed correctly with space group and all."""
+        phase = Phase.from_cif(cif_file)
+        assert phase.space_group.number == 12
+        assert phase.point_group.name == "2/m"
+        assert len(phase.structure) == 22  # Number of atoms
+        lattice = phase.structure.lattice
+        assert np.allclose(lattice.abcABG(), [15.5, 4.05, 6.74, 90, 105.3, 90])
+        assert np.allclose(
+            lattice.base, [[15.5, 0, 0], [0, 4.05, 0], [-1.779, 0, 6.501]], atol=1e-3
+        )
+
 
 class TestPhaseList:
     @pytest.mark.parametrize("empty_input", [(), [], {}])
